#!/bin/bash
#
#############################################################################
#       Author : florent robinet (LAL - Orsay): robinet@lal.in2p3.fr        #
#############################################################################

# move to the script directory
cd `dirname $0`

if [ $# -eq 1 ]; then tag=$1
else 
    # setup
    source ../cmt/setup.sh
    # get tag
    tag=`cmt show version GWOLLUM`
    
    # Get GWOLLUMSet
    gwset=`cmt show clients GWOLLUM $tag | grep GWOLLUMSet | tail -n 1 | awk '{print $4"/"$2"/"$3}'`

    # source GWOLLUM friends
    source ${gwset}/cmt/setup.sh
    #echo ${gwset}/cmt/setup.sh
fi

# get outdir
outdir=$GWOLLUM_WEB

echo "web directory: $outdir"
echo "tag: $tag"

# check outdir
if [ ! -d $outdir ]; then
    echo "`basename $0`: $outdir does not exist"
    exit 1
fi
outdir="${outdir}/GWOLLUM/${tag}"
mkdir -p $outdir

# export index
cp -f ./style.css ${outdir}/
cp -f ./header.html ${outdir}/
cp -f ./index.html ${outdir}/
cp -f ./left.html ${outdir}/
sed -i 's|\[VERSION_TAG\]|'${tag}'|g' ${outdir}/*.html

# export main pages
cp -fr ./Main/ ${outdir}/
sed -i 's|\[VERSION_TAG\]|'${tag}'|g' ${outdir}/Main/*.html

# export images
cp -fr ./Pics/ ${outdir}/

# export documentation (introduction pages)
cp -fr ./Documentation ${outdir}/
sed -i 's|\[VERSION_TAG\]|'${tag}'|g' ${outdir}/Documentation/*.html

# export friends
cp -fr ./Friends ${outdir}/
sed -i 's|\[VERSION_TAG\]|'${tag}'|g' ${outdir}/Friends/*.html

# export demos
cp -fr ./Demo ${outdir}/

if [ $# -eq 1 ]; then 
    echo "doxygen must be run by hand"
    exit 0; 
fi

# doxygen
mkdir -p ${outdir}/doxygen; rm -fr ${outdir}/doxygen/*
sed -e "s|\[VERSION\]|${tag}|g" \
    -e "s|\[GWOLLUMROOT\]|${GWOLLUMROOT}|g" \
    -e "s|\[OMICRONROOT\]|${OMICRONROOT}|g" \
    -e "s|\[G2GROOT\]|${G2GROOT}|g" \
    -e "s|\[OUTDIR\]|${outdir}/doxygen|g" \
    ./config.template.dox > ${outdir}/config.dox
doxygen ${outdir}/config.dox

#cd ${outdir}/doxygen/latex
#make






# exit
exit 0
